Git integration for ref-based diffs.
Enums
- DiffArg
- What a diff argument resolved to.
Functions
- classify_
diff_ arg - Classify a diff argument as a snapshot file or git ref.
- is_
git_ repo - Check whether the given path is inside a git repository.
- repo_
root - Find the git repository root from any path inside it.