#[non_exhaustive]pub struct ModuleGraph {
pub modules: Vec<Module>,
pub edges: Vec<Edge>,
pub forward_adj: Vec<Vec<EdgeId>>,
pub path_to_id: HashMap<PathBuf, ModuleId>,
pub package_map: HashMap<String, PackageInfo>,
}Expand description
A directed graph of modules connected by import edges.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.modules: Vec<Module>edges: Vec<Edge>forward_adj: Vec<Vec<EdgeId>>Outgoing edges per module (indexed by ModuleId)
path_to_id: HashMap<PathBuf, ModuleId>package_map: HashMap<String, PackageInfo>Implementations
Sourceimpl ModuleGraph
impl ModuleGraph
pub fn new() -> Self
pub fn add_module( &mut self, path: PathBuf, size_bytes: u64, package: Option<String>, ) -> ModuleId
pub fn add_edge( &mut self, from: ModuleId, to: ModuleId, kind: EdgeKind, specifier: &str, ) -> EdgeId
pub fn module(&self, id: ModuleId) -> &Module
pub fn edge(&self, id: EdgeId) -> &Edge
pub fn outgoing_edges(&self, id: ModuleId) -> &[EdgeId]
pub fn module_count(&self) -> usize
Sourcepub fn compute_package_info(&mut self)
pub fn compute_package_info(&mut self)
Compute aggregated package info (total reachable size + file count). For each package, BFS from its entry module following only edges within the same package.