Module loader

Module loader 

Entry point for building or loading a cached dependency graph.

Structs

LoadedGraph
Result of loading or building a dependency graph.

Functions

load_graph
Load a dependency graph using the real filesystem.
load_graph_with_vfs
Load a dependency graph from the given entry point using a custom VFS.