#[non_exhaustive]pub struct TraceResult {
pub static_weight: u64,
pub static_module_count: usize,
pub dynamic_only_weight: u64,
pub dynamic_only_module_count: usize,
pub heavy_packages: Vec<HeavyPackage>,
pub modules_by_cost: Vec<ModuleCost>,
pub all_packages: HashMap<String, u64>,
pub dynamic_packages: HashMap<String, u64>,
}Expand description
Results of tracing transitive import weight from an entry module.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.static_weight: u64Total file size reachable via static imports
static_module_count: usizeNumber of modules reachable via static imports
dynamic_only_weight: u64Total file size reachable only via dynamic imports (not already counted in static)
dynamic_only_module_count: usizeNumber of modules reachable only via dynamic imports
heavy_packages: Vec<HeavyPackage>Heavy packages found via static imports, sorted by total reachable size descending
modules_by_cost: Vec<ModuleCost>All reachable modules with their exclusive weight, sorted descending
all_packages: HashMap<String, u64>All statically reachable packages with their total size
dynamic_packages: HashMap<String, u64>Packages reachable only via dynamic imports (not in static set)
Implementations
Sourceimpl TraceResult
impl TraceResult
pub fn to_snapshot(&self, entry: &str) -> TraceSnapshot