Module report

Module report 

Human-readable output formatting for trace results, diffs, and package lists.

Structs

ChainReport
Display-ready chain result. Produced by Session::chain_report().
CutEntry
CutReport
Display-ready cut result. Produced by Session::cut_report().
DiffPackageEntry
DiffReport
Display-ready diff result. Produced by Session::diff_report() or DiffReport::from_diff().
ModuleEntry
PackageEntry
PackageListEntry
PackagesReport
Display-ready packages list. Produced by Session::packages_report().
StderrColor
TraceReport
Display-ready trace result. Produced by Session::trace_report().

Constants

DEFAULT_TOP
Default number of heavy dependencies to display.
DEFAULT_TOP_MODULES
Default number of modules by exclusive weight to display.

Functions

format_size
print_load_status
Print the standard graph-load status line plus any warnings.
relative_path
should_use_color
Determine whether color output should be used for a given stream.