pub fn entry_label(path: &Path, root: &Path) -> String
Build a display label for an entry point that includes the project directory name for disambiguation (e.g. wrangler/src/index.ts instead of just src/index.ts).
wrangler/src/index.ts
src/index.ts