Module git

Module git 

Git integration for ref-based diffs.

Enums

DiffArg
What a diff argument resolved to.

Functions

classify_diff_arg
Classify a diff argument as a snapshot file or git ref.
is_git_repo
Check whether the given path is inside a git repository.
repo_root
Find the git repository root from any path inside it.