Git integration for ref-based diffs.
Structs
- Temp
Worktree - A temporary git worktree that cleans up on drop.
Enums
- DiffArg
- What a diff argument resolved to.
Functions
- classify_
diff_ arg - Classify a diff argument as a snapshot file or git ref.
- create_
worktree - Create a temporary worktree checked out at the given git ref.
- is_
git_ repo - Check whether the given path is inside a git repository.
- repo_
root - Find the git repository root from any path inside it.