pub fn detect_project(entry: &Path) -> Option<(PathBuf, ProjectKind)>Expand description
Detect the project kind from the entry file extension, then walk up
to find the matching project root marker. Returns None for
unsupported file extensions.
pub fn detect_project(entry: &Path) -> Option<(PathBuf, ProjectKind)>Detect the project kind from the entry file extension, then walk up
to find the matching project root marker. Returns None for
unsupported file extensions.