Module loader

Module loader 

Entry point for building or loading a cached dependency graph.

Structs

LoadedGraph
Result of loading or building a dependency graph.

Functions

load_graph
Load a dependency graph from the given entry point.