Human-readable output formatting for trace results, diffs, and package lists.
Structs
- Chain
Report - Display-ready chain result. Produced by
Session::chain_report(). - CutEntry
- CutReport
- Display-ready cut result. Produced by
Session::cut_report(). - Diff
Package Entry - Diff
Report - Display-ready diff result. Produced by
Session::diff_report()orDiffReport::from_diff(). - Module
Entry - Package
Entry - Package
List Entry - Packages
Report - Display-ready packages list. Produced by
Session::packages_report(). - Stderr
Color - Trace
Report - Display-ready trace result. Produced by
Session::trace_report().
Constants
- DEFAULT_
TOP - Default number of heavy dependencies to display.
- DEFAULT_
TOP_ MODULES - Default number of modules by exclusive weight to display.
Functions
- format_
size - print_
load_ status - Print the standard graph-load status line plus any warnings.
- relative_
path - should_
use_ color - Determine whether color output should be used for a given stream.