Human-readable output formatting for trace results, diffs, and package lists.
Structs
Constants
- DEFAULT_
TOP - Default number of heavy dependencies to display.
- DEFAULT_
TOP_ MODULES - Default number of modules by exclusive weight to display.
Functions
- format_
size - print_
chains - print_
chains_ json - print_
cut - print_
cut_ json - print_
diff - print_
load_ status - Print the standard graph-load status line plus any warnings.
- print_
packages - print_
packages_ json - print_
trace - print_
trace_ json - relative_
path - should_
use_ color - Determine whether color output should be used for a given stream.