Module report

Module report 

Human-readable output formatting for trace results, diffs, and package lists.

Structs

DisplayOpts
StderrColor

Functions

format_size
print_chains
print_chains_json
print_cut
print_cut_json
print_diff
print_packages
print_packages_json
print_trace
print_trace_json
relative_path
should_use_color
Determine whether color output should be used for a given stream.