Human-readable output formatting for trace results, diffs, and package lists.
Structs
Functions
- format_
size - print_
chains - print_
chains_ json - print_
cut - print_
cut_ json - print_
diff - print_
packages - print_
packages_ json - print_
trace - print_
trace_ json - relative_
path - should_
use_ color - Determine whether color output should be used for a given stream.